# AudioCodes SBC Prometheus exporter
This is an exporter that exposes information gathered from AudioCodes SBC for use by the Prometheus monitoring system.

**This is a work in progress!!**

## Installation
`pip install audiocodes-exporter`

## Requirements
AudioCodes SBC v7.4
Python 3.10+